/**
 * License Agreement.
 *
 *  JBoss RichFaces - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces;

import org.ajax4jsf.test.base.RichSeleniumTest;
import org.ajax4jsf.test.base.SeleniumTestBase;
import org.ajax4jsf.test.base.Templates;
import org.testng.Assert;
import org.testng.annotations.AfterTest;
import org.testng.annotations.BeforeTest;
import org.testng.annotations.Parameters;
import org.testng.annotations.Test;

public class OrderingListTest  extends SeleniumTestBase implements RichSeleniumTest {
	
	public OrderingListTest() {
		super("http", "localhost", "8080");
	}
	
	public OrderingListTest(String protocol, String host, String port) {
		super(protocol, host, port);
		// TODO Auto-generated constructor stub
	}
	
	/**
     * This method are invoking before selenium tests started
     */
    @BeforeTest
    @Parameters( { "browser" })
    public void startSelenium(String browser) {
    	super.startSelenium(browser);
    }
    
    /**
     * This method are invoking after selenium tests completed
     */
    @AfterTest
    public void stopSelenium() {
    	super.stopSelenium();
    }
    
    @Test
    public void testOrderingListComponent() throws Exception {
    	_testOrderingListComponent(Templates.SIMPLE);
    	_testOrderingListComponent(Templates.DATATABLE);
    }

	private void _testOrderingListComponent(Templates template) {
		renderPage(getTestUrl(), template);
		
		String firstRowPrefix = getParentId() + "_form:orderingList:0:";
		String textId = firstRowPrefix + "output";
		
		checkButtons(true, true, true, true);
		clickById(textId);
		checkButtons(true, true, false, false);
		
	}
	
	public String getTestUrl() {
		return "/faces/pages/orderingList/orderingListTest.xhtml";
	}
	
	private void checkButtons(boolean firstDisabled, boolean upDisabled, boolean downDisabled, boolean lastDisabled) {
		String parentId = getParentId() + "_form:orderingList";
		String firstButton = parentId + "first";
		String firstButtonDisabled = parentId + "disfirst";
		
		String upButton = parentId + "up";
		String upButtonDisabled = parentId + "disup";
		
		String downButton = parentId + "down";
		String downButtonDisabled = parentId + "disdown";
		
		String lastButton = parentId + "last";
		String lastButtonDisabled = parentId + "dislast";
		
		if (firstDisabled) {
			Assert.assertTrue(isVisibleById(firstButtonDisabled));
			Assert.assertFalse(isVisibleById(firstButton));
		} else {
			Assert.assertFalse(isVisibleById(firstButtonDisabled));
			Assert.assertTrue(isVisibleById(firstButton));
		}
		
		if (upDisabled) {
			Assert.assertTrue(isVisibleById(upButtonDisabled));
			Assert.assertFalse(isVisibleById(upButton));
		} else {
			Assert.assertFalse(isVisibleById(upButtonDisabled));
			Assert.assertTrue(isVisibleById(upButton));
		}
		
		if (downDisabled) {
			Assert.assertTrue(isVisibleById(downButtonDisabled));
			Assert.assertFalse(isVisibleById(downButton));
		} else {
			Assert.assertFalse(isVisibleById(downButtonDisabled));
			Assert.assertTrue(isVisibleById(downButton));
		}
		
		if (lastDisabled) {
			Assert.assertTrue(isVisibleById(lastButtonDisabled));
			Assert.assertFalse(isVisibleById(lastButton));
		} else {
			Assert.assertFalse(isVisibleById(lastButtonDisabled));
			Assert.assertTrue(isVisibleById(lastButton));
		}
	}
}
